pub fn focused_pane_command() -> Result<Option<String>>Expand description
Returns the running command of the currently focused pane by parsing zellij action list-clients.
Returns None if the command column is empty (default shell) or parsing fails.
Errors
- Invoking
zellij action list-clientsfails.