pub fn new_session_with_layout(session: &str, layout: &str) -> Result<()>Expand description
Creates a new Zellij session with the given layout and attaches to it.
Must be called from outside Zellij — the process replaces the current terminal with the new session (interactive, inherited stdio).
Errors
- Invoking
zellijfails or exits with a nonzero exit status.